@@ -684,7 +684,9 @@ class CommandV(Extensible):
         self.__config.check_config('deactivate_backup')
         db_config = self.instance_manager.db_config
         db_helper_class = database_helper.DatabaseHelper.get_helper(use_template=False)
-        db_helper = db_helper_class(utils.odoo2postgres(db_config))
+        db_helper = db_helper_class(
+            utils.odoo2postgres(db_config), self.instance_manager._get_admin_config(),
+            self.__config.postgres.get('extensions'))
         candidate = db_helper.search_candidate(self.__config.backup_src, self.__config.prefix)
         prefix = '{prefix}_deactivated'.format(prefix=self.__config.prefix)
         db_name = utils.generate_dbname({}, candidate[1], prefix)
@@ -1110,8 +1112,11 @@ class CommandV(Extensible):
         db_name = db_name or utils.generate_dbname(self.__config, False, self.__config.prefix)
         postgres = postgresv.PostgresShell(utils.odoo2postgres(self.instance_manager.db_config))
         postgres.create(db_name)
-        create_date = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+        postgres_admin = postgresv.PostgresShell(self.instance_manager._get_admin_config())
+        for extension in self.__config.postgres.get('extensions'):
+            postgres_admin.create_extension(db_name, extension)
         self.instance_manager.create_extension_unaccent(db_name)
+        create_date = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
         self.instance_manager.update_db(db_name, ['all'])
         res.get('result').update({'database_name': db_name, 'create_date': create_date})
         params = {'database.generated_at': create_date,
@@ -1312,19 +1317,21 @@ class CommandV(Extensible):
         res = {'result': {}}
         # Commit container and push image
         manager = self.__instance_manager
+        variables = manager.config_variables
         image_name = self.__config.container_config.get('image_name')
         image_repo = image_name.split(':')[0]
-        image_tag = utils.get_strtime()
-        self.sender.send_message('Pushing image {}:{}'.format(image_repo, image_tag))
-        commit_result = manager.commit_and_push(image_repo, image_tag)
+        base_tag_name = "%(app)s-%(version)s" % {
+            "app": variables.get("main_app"), "version": variables.get("version")}
+        date_tag = "%(base)s-%(date)s" % {
+            "base": base_tag_name, "date": utils.get_strtime()}
+        self.sender.send_message('Pushing image {}:{}'.format(image_repo, date_tag))
+        commit_result = manager.commit_and_push(image_repo, date_tag)
         if commit_result.get('error'):
             res.update({'error': commit_result.get('error')})
             return res
         # Tag updates as stable and push
         self.sender.send_message('Pushing scheduled image {} as stable'.format(image_name))
-        variables = self.instance_manager.config_variables
-        tag = "%(app)s-%(version)s-stable" % {
-            "app": variables.get("main_app"), "version": variables.get("version")}
+        tag = "%(base)s-stable" % {"base": base_tag_name}
         tag_result = manager.tag_and_push(image_name, image_repo, tag=tag)
         if tag_result.get('error'):
             res.update({'error': tag_result.get('error')})
