@@ -67,7 +67,6 @@ import simplejson as json
 from deployv.helpers import container
 from deployv.helpers.utils import get_error_message, decode
 from deployv.base import errors
-import re
 from retry_decorator import retry
 from time import sleep
 
@@ -479,27 +478,35 @@ class DockerV:
 
     @retry(docker.errors.APIError, tries=3, timeout_secs=0.5, logger=logger)
     def pull(self, image_name=False, raise_exception=False):
-        """This is a simple wrapper for docker pull to use the deployv exceptions instead of the
+        """Make a pull of image with provided name.
+
+        :param image_name: Name of image to pull.
+        :type image_name: str
+        :param raise_exception: Indicates if raises an exception when no image got from cli's pull
+        :type raise_exception: bool
+        """
+        image_name = image_name or self.config.get('image_name')
+        try:
+            self.cli_pull_wrapper(image_name=image_name)
+        except errors.NoSuchImage as exc:
+            if raise_exception:
+                raise exc
+            image = self.inspect_image(image_name)
+            logger.debug('Image info %s', image)
+
+    def cli_pull_wrapper(self, image_name=False):
+        """This is a simple wrapper for docker pull, to use the deployv exceptions instead of the
         docker ones.
 
         :param image_name: The image name to pull.
         :type image_name: str
-        :param raise_execption: Identificator to know if raise the exepction.
-        :type raise_execption: bool
+        :raises: :class:`~deployv.base.errors.NoSuchImage` if the image doesn't exist.
         """
-        image_name = image_name or self.config.get('image_name')
-        valid_image = re.match('(?:.*/)?.*/.*:.*', image_name)
-        if not valid_image:
-            logger.warning("The image %s is in bad format and cannot be pulled", image_name)
-            return
         try:
             self.cli.pull(image_name)
         except docker.errors.NotFound:
             logger.debug('Image not found in hub')
-            if raise_exception:
-                raise errors.NoSuchImage(image_name)
-            image = self.inspect_image(image_name)
-            logger.debug('Image info %s', image)
+            raise errors.NoSuchImage(image_name)
 
     @retry(docker.errors.APIError, tries=3, timeout_secs=0.5, logger=logger)
     def push(self, image_name):
@@ -620,6 +627,21 @@ class DockerV:
         return res
 
     def inspect_image(self, image_name):
+        """Inspect image with provided name, returning its params.
+
+        :param image_name: The image name that will be inspected.
+        :type image_name: str
+        :returns: The result of docker inspect_image.
+        :raises: :class:`~deployv.base.errors.NoSuchImage` when image doesn't exist
+        """
+        try:
+            self.cli_pull_wrapper(image_name)   # just in case does not exist in local
+        except errors.NoSuchImage:
+            pass
+        res = self.cli_inspect_image_wrapper(image_name)
+        return res
+
+    def cli_inspect_image_wrapper(self, image_name):
         """Wrapper for the inspect image, basically does the same but raises a deployv exception
         instead of the docker-py one.
 
@@ -629,7 +651,6 @@ class DockerV:
         :raises: :class:`~deployv.base.errors.NoSuchImage` if the image doesn't exist.
         """
         try:
-            self.pull(image_name)
             res = self.cli.inspect_image(image_name)
         except docker.errors.NotFound:
             raise errors.NoSuchImage(image_name)
@@ -817,6 +838,8 @@ class DockerV:
         :type: str
         """
         image = image or self.config.get('image_name')
+        if not image:
+            return
         self.pull(image)
         volumes = volumes or self.config.get('volumes')
         env_vars = self.docker_env
@@ -832,7 +855,9 @@ class DockerV:
                 'Waiting for the command to finish, current state: %s', cont.status)
             sleep(5)
             cont.reload()
+        res = cont.logs()
         cont.remove()
+        return res and res.decode()
 
     def get_env_from_image(self, image=False):
         """Get the environment of a specific image or use the image set in the config,
