@@ -261,7 +261,6 @@ class PostgresShell:
         """Executes a *createdb* command.
 
         :param database_name: Database name.
-        :type database_name: str
         :returns: The created database name.
         :rtype: str
         """
@@ -290,6 +289,8 @@ class PostgresShell:
         :type database_name: str
         :param dump_name: Full path and name of the sql dump to restore.
         :type dump_name: str
+        :param jobs: How many jobs will be used to restore the database, none by default
+        :type dump_name: int
         :returns: If succeeded (True) or not (None).
         :rtype: bool or None
         """
@@ -306,7 +307,6 @@ class PostgresShell:
         restore_cmd = self.__format_cmd(restore_cmd, cnf)
         restore_cmd = restore_cmd.format(dump_name, **cnf)
         shell = spur.LocalShell()
-        self.create(database_name)
         try:
             shell.run(shlex.split(restore_cmd))
         except spur.results.RunProcessError as error:
@@ -319,28 +319,40 @@ class PostgresShell:
         return res
 
     def create_extension_unaccent(self, database_name):
-        """ Creates the unaccent extension in the specified database
+        """ Creates the unaccent extension in the specified database.
+        Keeping this for not braking anything unexpected
 
         :param database_name: Name of the database where the extension will be created
         """
+        logger.info('Creating extension unaccent in the database %s', database_name)
+        self.create_extension(database_name, 'unaccent')
+
+    def create_extension(self, database_name, extension_name):
+        """ Creates the given extension_name in the database_name.
+        The credentials must have permission to create extensions, generally a superuser.
+
+        :param database_name: The database where you want to create the extension
+        :param extension_name: The extension name
+        :return: None
+        """
         config = self.__config.copy()
         config.update({'dbname': database_name})
-        logger.info('Creating extension unaccent in the database %s', database_name)
+        logger.info('Creating extension %s in the database %s', extension_name, database_name)
         try:
             with PostgresConnector(config) as db:
-                db.execute("create extension unaccent;")
+                db.execute("create extension {};".format(extension_name))
         except (psycopg2.ProgrammingError, psycopg2.OperationalError) as error:
             error_msg = utils.get_error_message(error)
             allowed_errors = ['permission denied to create extension',
                               'password authentication failed']
-            if '"unaccent" already exists' in error_msg:
+            if 'already exists' in error_msg:
                 logger.info(error_msg.strip())
                 return
             if any(err in error_msg for err in allowed_errors):
                 logger.error(
-                    'Unable to create the unaccent extension, authentication for the'
+                    'Unable to create the %s extension, authentication for the'
                     ' postgres user in the deployv.conf file failed or the'
-                    ' user is not superuser'
+                    ' user is not superuser', extension_name
                 )
                 return
             raise
