@@ -782,7 +782,9 @@ class InstanceV(DockerV):
         use_template = self.__full_config.container_config.get('use_template')
         jobs = self.__full_config.jobs or 5
         helper_obj = database_helper.DatabaseHelper.get_helper(use_template)
-        db_helper = helper_obj(utils.odoo2postgres(self.db_config))
+        db_helper = helper_obj(
+            utils.odoo2postgres(self.db_config), self._get_admin_config(),
+            self.__full_config.postgres.get('extensions'))
         backup_dir = backup_dir or self.__full_config.backup_src
         res_search = db_helper.search_candidate(backup_dir, customer_id)
         if not res_search[0]:
@@ -1385,8 +1387,9 @@ class InstanceV(DockerV):
         destroying a container so they are not present the next time we deploy the same container
         """
         logger.info('Cleaning volumes')
+        use_snapshot = self.__full_config.backup_type in ['btrfs', 'zfs']
         for key, volume in self.config.get('volumes').items():
-            if self.config.get('keep_db') and key == 'filestore':
+            if (self.config.get('keep_db') or use_snapshot) and key == 'filestore':
                 continue
             logger.info('Removing volume: %s', volume)
             self.exec_cmd('rm -rf {volume}'.format(volume=volume))
@@ -1533,8 +1536,10 @@ class InstanceV(DockerV):
         env_vars = self.config.get('env_vars') or self.docker_env
         odoo_home = env_vars.get('odoo_home')
         cmd = "find {0}/instance -name 'deactivate.jinja'".format(odoo_home)
+        wf_path = self.__full_config.working_folder
+        name = path.basename(wf_path)
         try:
-            res_cmd = self.exec_cmd(cmd)
+            res_cmd = self.exec_cmd_image(cmd, {name: '/tmp'}, wf_path)
         except errors.CommandError:
             return res
         if not res_cmd or 'No such file or directory' in res_cmd:
@@ -1543,7 +1548,7 @@ class InstanceV(DockerV):
         for file_sql in res_cmd.splitlines():
             if not file_sql:
                 continue
-            sqls = self.exec_cmd("cat {0}".format(file_sql))
+            sqls = self.exec_cmd_image("cat {0}".format(file_sql), {name: '/tmp'}, wf_path)
             sql_json = json_helper.load_json(Template(sqls).render(**env_vars))
             res.update(sql_json or {})
         return res
@@ -1598,18 +1603,20 @@ class InstanceV(DockerV):
             render the deactivation.jinja file
         """
         logger.info('Deactivating database %s', db_name)
-        db_config = self.db_config.copy()
-        db_config.update({
-            'db_name': db_name,
-            'db_user': db_config.get("db_owner") or db_config.get('db_user'),
-            'db_password': db_config.get('db_owner_passwd') or db_config.get('db_password'),
+        db_config_user = self.db_config.copy()
+        db_config_user.update({'db_name': db_name})
+        db_config_owner = db_config_user.copy()
+        db_config_owner.update({
+            'db_user': self.db_config.get("db_owner"),
+            'db_password': self.db_config.get('db_owner_passwd')
         })
-        db_config = utils.odoo2postgres(db_config)
+        db_config_user = utils.odoo2postgres(db_config_user)
+        db_config_owner = utils.odoo2postgres(db_config_owner)
         extra_config = extra_config or {}
         extra_sqls = self.extras_deactivate()
         query_config = ("select id from ir_model_fields where name"
                         "= 'value' and model = 'ir.config_parameter';")
-        config_parameter_id = self.execute_query(db_config, query_config)
+        config_parameter_id = self.execute_query(db_config_user, query_config)
         config_parameter_id = config_parameter_id and config_parameter_id[0].get('id')
         extra_config.update({
             'field_id': config_parameter_id, 'uuid': uuid4(),
@@ -1630,7 +1637,12 @@ class InstanceV(DockerV):
             for name in sorted(sqls):
                 logger.debug('Running %s', name)
                 sql = sqls[name]
-                self.execute_query(db_config, sql, allow_errors=True)
+                try:
+                    self.execute_query(db_config_user, sql, allow_errors=True)
+                except psycopg2.errors.InsufficientPrivilege as error:
+                    logger.warning("Inssufficient permissions for user '%s': %s",
+                                   db_config_user.get('user'), utils.get_error_message(error))
+                    self.execute_query(db_config_owner, sql, allow_errors=True)
         except psycopg2.OperationalError as error:
             logger.exception('Could not deactivate the database: %s', error.message)
 
@@ -1787,13 +1799,16 @@ print(json.dumps({
         :param db_name: name of the database where the extension will
             be created.
         """
+        pg_shell = PostgresShell(self._get_admin_config())
+        pg_shell.create_extension_unaccent(db_name)
+
+    def _get_admin_config(self):
         admin_config = self.db_config.copy()
         admin_config.update({
             'db_user': self.__full_config.postgres.get('db_user'),
             'db_password': self.__full_config.postgres.get('db_password'),
         })
-        pg_shell = PostgresShell(utils.odoo2postgres(admin_config))
-        pg_shell.create_extension_unaccent(db_name)
+        return utils.odoo2postgres(admin_config)
 
 
 class DummyInstanceV:
